@@ -99,14 +99,16 @@ sub do_http {
 			my ($body, $headers) = @_;
 			my ($is_success, $status, $h, $redirects) = headers($headers);
 
-			if (not $body and @body_from_on_body) {
-				if ($status == 598) {
-					$body = "";
-					$$h{'client-aborted'} = 'max_size';
-					$$h{$_} = delete $$h{"Orig$_"} foreach qw(Status Reason);
-					$status = $$h{Status};
-					$is_success = ($status >= 200 and $status < 300) ? 1 : 0;
-				} else {
+			if (not $body) {
+				if ($status >= 590) {
+					$is_success   = 0;
+					$body         = "";
+					if ($status == 598) {
+						$$h{"Reason"} = "MaxSize";
+					}
+					$$h{"Status"} = $status = 599;
+					delete $$h{"Orig$_"} foreach qw(Status Reason);
+				} elsif (@body_from_on_body) {
 					$body = join "", @body_from_on_body;
 				}
 			}
