@@ -3,7 +3,7 @@ package HTTP::Any::Curl;
 use strict;
 use warnings;
 
-use Net::Curl::Easy qw(/^CURLOPT_/ CURLE_OK CURLE_WRITE_ERROR CURLINFO_EFFECTIVE_URL);
+use Net::Curl::Easy qw(/^CURLOPT_/ CURLE_OK CURLINFO_EFFECTIVE_URL CURLE_WRITE_ERROR CURLE_OPERATION_TIMEDOUT);
 
 
 BEGIN {
@@ -48,7 +48,7 @@ sub do_http {
 	$easy->setopt(CURLOPT_HTTPHEADER, \@headers) if @headers;
 
 	$easy->setopt(CURLOPT_FOLLOWLOCATION, 1);
-	$easy->setopt(CURLOPT_MAXREDIRS, 5);
+	$easy->setopt(CURLOPT_MAXREDIRS, 10);
 
 
 	if ($$opt{cookie}) {
@@ -116,11 +116,17 @@ sub do_http {
 		if ($headers) {
 			my ($is_success, $headers, $redirects) = headers($easy, $url, $headers);
 			if ($result == CURLE_WRITE_ERROR and $aborted_by_max_size) {
-				$$headers{'client-aborted'} = 'max_size';
+				$is_success = 0;
+				$$headers{"Status"} = 599;
+				$$headers{"Reason"} = "MaxSize";
+			} elsif ($result == CURLE_OPERATION_TIMEDOUT) {
+				$is_success = 0;
+				$$headers{"Status"} = 599;
+				$$headers{"Reason"} = "Timeout";
 			}
 			$cb->($is_success, $body, $headers, $redirects);
 		} else {
-			$cb->(0, undef, { Status => 500, Reason => $easy->error(), URL => $url }, []);
+			$cb->(0, undef, { Status => 500, Reason => "$result", URL => $url }, []);
 		}
 
 	};
